## xpublish-wms

[![PyPI](https://img.shields.io/pypi/v/xpublish-wms)](https://pypi.org/project/xpublish-wms/)
[![Conda Version](https://img.shields.io/conda/vn/conda-forge/xpublish-wms.svg)](https://anaconda.org/conda-forge/xpublish-wms)

[![Tests](https://github.com/xpublish-community/xpublish-wms/actions/workflows/tests.yml/badge.svg)](https://github.com/xpublish-community/xpublish-wms/actions/workflows/tests.yml)
[![pre-commit.ci status](https://results.pre-commit.ci/badge/github/xpublish-community/xpublish-wms/main.svg)](https://results.pre-commit.ci/latest/github/xpublish-community/xpublish-wms/main)

[Xpublish](https://xpublish.readthedocs.io/en/latest/) routers for the [OGC WMS API](https://www.ogc.org/standards/wms).

### Documentation and code

URLs for the docs and code.

### Installation

For `conda` users you can

```shell
conda install --channel conda-forge xpublish_wms
```

or, if you are a `pip` users

```shell
pip install xpublish_wms
```

Once it's installed, the plugin will register itself with Xpublish and WMS endpoints will be included for each dataset on the server.

## Get in touch

Report bugs, suggest features or view the source code on [GitHub](https://github.com/xpublish-community/xpublish-wms/issues).


## License and copyright

xpublish-wms is licensed under BSD 3-Clause "New" or "Revised" License (BSD-3-Clause).

Development occurs on GitHub at <https://github.com/xpublish-community/xpublish-wms>.
